Mailinglist Archive: opensuse-commit (1206 mails)
| < Previous | Next > |
commit hal
- From: root@xxxxxxx (h_root)
- Date: Sun, 7 May 2006 16:19:02 +0200 (CEST)
- Message-id: <20060507141902.A537F8C5C2@xxxxxxxxxxxxxxx>
Hello community,
here is the log from the commit of package hal
checked in at Sun May 7 16:19:02 CEST 2006.
--------
--- hal/hal.changes 2006-04-25 14:02:32.000000000 +0200
+++ STABLE/hal/hal.changes 2006-05-04 19:50:40.000000000 +0200
@@ -1,0 +2,34 @@
+Thu May 4 15:12:32 CEST 2006 - dkukawka@xxxxxxx
+
+- added patches:
+ - hal-add-debug_to_syslog_probing_v2.diff: add debug to syslog
+ for prober and addons for better debugging and maintenance
+ - hal-fix-probe_smbios_parse_bug172204.diff: fix bug #172204
+ replaced sizeof(char *) with strlen(char *)
+- updated patches:
+ - hal-add-wacom_tabletPC.diff: fixed compiler warning
+
+-------------------------------------------------------------------
+Wed May 3 15:29:34 CEST 2006 - dkukawka@xxxxxxx
+
+- removed and merged patches:
+ - merged system.formfactor patches together to:
+ hal-fix-map_chassitype_to_formfactor_v2.diff
+- added patches:
+ - hal-fix-int-size-for-alignment-error-01.patch: fix for #146237
+ - hal-fix-mount_on_dev_wo_media_check_support.diff:
+ fix for #164327
+
+-------------------------------------------------------------------
+Wed May 3 12:02:26 CEST 2006 - thoenig@xxxxxxx
+
+- fix detection for system.formfactor (b.n.c #169161)
+
+-------------------------------------------------------------------
+Wed May 3 10:01:01 CEST 2006 - olh@xxxxxxx
+
+- add hal-vio-bus.patch to allow CD/DVD install
+ handle bustype vio as found in IBM iSeries and pSeries LPAR
+ (167629 / 163971 - LTC21953 / 167137 - LTC23229)
+
+-------------------------------------------------------------------
Old:
----
hal-fix-map_chassitype_to_formfactor.diff
New:
----
hal-add-debug_to_syslog_probing_v2.diff
hal-fix-int-size-for-alignment-error-01.patch
hal-fix-map_chassitype_to_formfactor_v2.diff
hal-fix-mount_on_dev_wo_media_check_support.diff
hal-fix-probe_smbios_parse_bug172204.diff
hal-vio-bus.patch
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Other differences:
------------------
++++++ hal.spec ++++++
--- /var/tmp/diff_new_pack.J5FPPX/_old 2006-05-07 16:12:48.000000000 +0200
+++ /var/tmp/diff_new_pack.J5FPPX/_new 2006-05-07 16:12:48.000000000 +0200
@@ -19,7 +19,7 @@
License: Other License(s), see package, Other uncritical OpenSource License
Group: System/Daemons
Version: 0.5.6
-Release: 29
+Release: 32
Autoreqprov: on
Summary: Daemon for Collecting Hardware Information
# SUSE specific patches
@@ -31,6 +31,7 @@
Patch5: %{name}-fix-mount_159475.diff
Patch6: %{name}-fix-mount-sanitze-mountpoint.diff
Patch7: %{name}-performance-properties2.diff
+Patch8: %{name}-fix-mount_on_dev_wo_media_check_support.diff
# submitted upstream patches
Patch10: hal-update-copyright_header.diff
Patch11: hal-fix-mount_script_v4.diff
@@ -41,13 +42,15 @@
Patch16: hal-fix-mount_umount_only_by_hal_mounted_v2.diff
Patch17: hal-fix-mount_options_noexec.diff
Patch18: hal-fix-mount_script_fstab_check.diff
-Patch19: hal-fix-map_chassitype_to_formfactor.diff
+Patch19: hal-fix-map_chassitype_to_formfactor_v2.diff
Patch20: hal-fix-get_prober_serial.diff
Patch21: hal-add-usb-music_players_to_fdi_v2.diff
Patch22: hal-fix-apm_remaining_time.diff
Patch23: hal-fix-nfs_stall_block_hald.diff
Patch24: hal-fix-CD_DVD-capability.diff
Patch25: hal-fix-apm-poll_battery_reduce_events.diff
+Patch26: hal-add-debug_to_syslog_probing_v2.diff
+Patch27: hal-fix-probe_smbios_parse_bug172204.diff
# external patches from HAL List and backports
Patch100: hal-add-scsi-type.diff
Patch101: hal-fix-SG_IO_bug145147.diff
@@ -55,6 +58,8 @@
Patch103: hal-fix-udev-clean_buffer.diff
Patch104: hal-fix-storage-policy-fixed-drives.diff
Patch105: hal-fix-pcmcia_storage.diff
+Patch106: hal-vio-bus.patch
+Patch107: hal-fix-int-size-for-alignment-error-01.patch
# patches for testing:
Patch200: hal-change_to_hashtables.patch
# Sources:
@@ -171,6 +176,11 @@
%patch103
%patch104
%patch105
+%patch106
+%patch107
+%patch8
+%patch26
+%patch27
#%patch200
#rm -rf py-compile 4> /dev/null || :
#ln -s /usr/share/automake-1.9/py-compile py-compile 2> /dev/null || :
@@ -286,6 +296,28 @@
%{_bindir}/hal-device-manager
%changelog -n hal
+* Thu May 04 2006 - dkukawka@xxxxxxx
+- added patches:
+- hal-add-debug_to_syslog_probing_v2.diff: add debug to syslog
+ for prober and addons for better debugging and maintenance
+- hal-fix-probe_smbios_parse_bug172204.diff: fix bug #172204
+ replaced sizeof(char *) with strlen(char *)
+- updated patches:
+- hal-add-wacom_tabletPC.diff: fixed compiler warning
+* Wed May 03 2006 - dkukawka@xxxxxxx
+- removed and merged patches:
+- merged system.formfactor patches together to:
+ hal-fix-map_chassitype_to_formfactor_v2.diff
+- added patches:
+- hal-fix-int-size-for-alignment-error-01.patch: fix for #146237
+- hal-fix-mount_on_dev_wo_media_check_support.diff:
+ fix for #164327
+* Wed May 03 2006 - thoenig@xxxxxxx
+- fix detection for system.formfactor (b.n.c #169161)
+* Wed May 03 2006 - olh@xxxxxxx
+- add hal-vio-bus.patch to allow CD/DVD install
+ handle bustype vio as found in IBM iSeries and pSeries LPAR
+ (167629 / 163971 - LTC21953 / 167137 - LTC23229)
* Tue Apr 25 2006 - dkukawka@xxxxxxx
- activated patch:
- hal-performance-properties2.diff: only for SLES/SLED 10
++++++ hal-add-debug_to_syslog_probing_v2.diff ++++++
--- hald/util.c 2006-04-25 18:56:50.000000000 +0200
+++ hald/util.c 2006-05-03 23:32:55.000000000 +0200
@@ -697,6 +697,8 @@
num_env_vars++;
if (hald_is_initialising)
num_env_vars++;
+ if (hald_use_syslog)
+ num_env_vars++;
if ((local_addr = hald_dbus_local_server_addr ()) != NULL)
num_env_vars++;
@@ -709,6 +711,8 @@
envp[i++] = g_strdup ("HALD_VERBOSE=1");
if (hald_is_initialising)
envp[i++] = g_strdup ("HALD_STARTUP=1");
+ if (hald_use_syslog)
+ envp[i++] = g_strdup ("HALD_USE_SYSLOG=1");
if (local_addr != NULL)
envp[i++] = g_strdup_printf ("HALD_DIRECT_ADDR=%s", local_addr);
for (j = 0; j < num_extras; j++) {
--- hald/linux2/probing/shared.h 2006-05-03 23:36:33.000000000 +0200
+++ hald/linux2/probing/shared.h 2006-05-04 00:16:59.000000000 +0200
@@ -4,8 +4,10 @@
#include <time.h>
#include <sys/time.h>
+#include <sys/syslog.h>
static dbus_bool_t is_verbose = FALSE;
+static dbus_bool_t use_syslog = FALSE;
static void
_do_dbg (const char *format, va_list args)
@@ -29,7 +31,10 @@
tlocaltime = localtime (&tnow.tv_sec);
strftime (tbuf, sizeof (tbuf), "%H:%M:%S", tlocaltime);
- fprintf (stderr, "%d: %s.%03d: %s", pid, tbuf, (int)(tnow.tv_usec/1000), buf);
+ if (use_syslog)
+ syslog (LOG_INFO, "%d: %s.%03d: %s", pid, tbuf, (int)(tnow.tv_usec/1000), buf);
+ else
+ fprintf (stderr, "%d: %s.%03d: %s", pid, tbuf, (int)(tnow.tv_usec/1000), buf);
va_end (args);
}
@@ -42,6 +47,16 @@
_do_dbg (format, args);
}
+static void
+_set_debug ()
+{
+ if ((getenv ("HALD_VERBOSE")) != NULL)
+ is_verbose = TRUE;
+
+ if ((getenv ("HALD_USE_SYSLOG")) != NULL)
+ use_syslog = TRUE;
+}
+
#define dbg(format, arg...) \
do { \
_dbg ("%s:%d: " format "\n", __FILE__, __LINE__, ## arg); \
--- hald/linux2/probing/probe-smbios.c 2006-04-25 18:57:09.000000000 +0200
+++ hald/linux2/probing/probe-smbios.c 2006-05-04 00:17:32.000000000 +0200
@@ -104,15 +104,14 @@
/* assume failure */
ret = 1;
+ _set_debug ();
+
udi = getenv ("UDI");
if (udi == NULL) {
dbg ("UDI not set");
goto out;
}
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
-
dbus_error_init (&error);
if ((ctx = libhal_ctx_init_direct (&error)) == NULL) {
dbg ("ctx init failed");
--- hald/linux2/probing/probe-input.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/probing/probe-input.c 2006-05-04 14:51:30.000000000 +0200
@@ -162,9 +162,8 @@
if (device_file == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
-
+ _set_debug ();
+
dbg ("Doing probe-input for %s (udi=%s)",
device_file, udi);
--- hald/linux2/probing/probe-pc-floppy.c 2006-04-25 18:56:49.000000000 +0200
+++ hald/linux2/probing/probe-pc-floppy.c 2006-05-04 14:55:07.000000000 +0200
@@ -66,9 +66,7 @@
if ((device_file = getenv ("HAL_PROP_BLOCK_DEVICE")) == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
-
+ _set_debug ();
dbg ("Checking if %s is actually present", device_file);
--- hald/linux2/probing/probe-printer.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/probing/probe-printer.c 2006-05-04 14:56:14.000000000 +0200
@@ -75,9 +75,8 @@
if ((ctx = libhal_ctx_init_direct (&error)) == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
-
+ _set_debug ();
+
device_file = getenv ("HAL_PROP_PRINTER_DEVICE");
if (device_file == NULL)
goto out;
--- hald/linux2/probing/probe-serial.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/probing/probe-serial.c 2006-05-04 14:56:44.000000000 +0200
@@ -63,9 +63,7 @@
if ((device_file = getenv ("HAL_PROP_SERIAL_DEVICE")) == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
-
+ _set_debug ();
dbg ("Checking if %s is actually present", device_file);
--- hald/linux2/probing/probe-storage.c 2006-04-25 18:56:49.000000000 +0200
+++ hald/linux2/probing/probe-storage.c 2006-05-04 14:57:50.000000000 +0200
@@ -153,8 +153,7 @@
if ((drive_type = getenv ("HAL_PROP_STORAGE_DRIVE_TYPE")) == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
+ _set_debug ();
if (argc == 2 && strcmp (argv[1], "--only-check-for-media") == 0)
only_check_for_fs = TRUE;
--- hald/linux2/probing/probe-volume.c 2006-04-25 18:56:49.000000000 +0200
+++ hald/linux2/probing/probe-volume.c 2006-05-04 14:58:59.000000000 +0200
@@ -327,8 +327,7 @@
else
is_disc = FALSE;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
+ _set_debug ();
dbus_error_init (&error);
if ((ctx = libhal_ctx_init_direct (&error)) == NULL)
--- hald/linux2/addons/addon-acpi.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/addons/addon-acpi.c 2006-05-04 14:59:29.000000000 +0200
@@ -151,8 +151,7 @@
DBusError error;
FILE *eventfp;
- if (getenv ("HALD_VERBOSE") != NULL)
- is_verbose = TRUE;
+ _set_debug ();
dbus_error_init (&error);
--- hald/linux2/addons/addon-hid-ups.c 2006-01-11 15:13:47.000000000 +0100
+++ hald/linux2/addons/addon-hid-ups.c 2006-05-04 15:42:01.000000000 +0200
@@ -112,7 +112,7 @@
if (ioctl (fd, HIDIOCGSTRING, &sdesc) < 0) {
return "";
}
- fprintf (stderr, "foo: '%s'\n", sdesc.value);
+ dbg ("foo: '%s'", sdesc.value);
return sdesc.value;
}
@@ -272,6 +272,8 @@
struct hiddev_event ev[64];
int rd;
+ _set_debug ();
+
udi = getenv ("UDI");
if (udi == NULL)
goto out;
--- hald/linux2/addons/addon-pmu.c 2006-04-25 18:56:47.000000000 +0200
+++ hald/linux2/addons/addon-pmu.c 2006-05-04 15:00:17.000000000 +0200
@@ -58,8 +58,7 @@
fd = -1;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
+ _set_debug ();
udi = getenv ("UDI");
if (udi == NULL)
--- hald/linux2/addons/addon-storage.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/addons/addon-storage.c 2006-05-04 15:02:40.000000000 +0200
@@ -171,8 +171,7 @@
if ((drive_type = getenv ("HAL_PROP_STORAGE_DRIVE_TYPE")) == NULL)
goto out;
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
+ _set_debug ();
storage_policy_should_mount_str = getenv ("HAL_PROP_STORAGE_POLICY_SHOULD_MOUNT");
@@ -186,11 +185,9 @@
if ((ctx = libhal_ctx_init_direct (&error)) == NULL)
goto out;
- printf ("**************************************************\n");
- printf ("**************************************************\n");
- printf ("Doing addon-storage for %s (bus %s) (drive_type %s) (udi %s)\n", device_file, bus, drive_type, udi);
- printf ("**************************************************\n");
- printf ("**************************************************\n");
+ dbg ("**************************************************");
+ dbg ("Doing addon-storage for %s (bus %s) (drive_type %s) (udi %s)", device_file, bus, drive_type, udi);
+ dbg ("**************************************************");
if (strcmp (drive_type, "cdrom") == 0)
is_cdrom = 1;
--- hald/linux2/addons/addon-usb-csr.c 2006-04-25 18:56:48.000000000 +0200
+++ hald/linux2/addons/addon-usb-csr.c 2006-05-04 15:04:29.000000000 +0200
@@ -260,9 +260,8 @@
main (int argc, char *argv[])
{
DBusError err;
-
- if ((getenv ("HALD_VERBOSE")) != NULL)
- is_verbose = TRUE;
+
+ _set_debug ();
device_udi = getenv ("UDI");
++++++ hal-add-wacom_tabletPC.diff ++++++
--- /var/tmp/diff_new_pack.J5FPPX/_old 2006-05-07 16:12:49.000000000 +0200
+++ /var/tmp/diff_new_pack.J5FPPX/_new 2006-05-07 16:12:49.000000000 +0200
@@ -33,7 +33,7 @@
+ if(_port == NULL)
+ goto out;
+
-+ port = strtok(_port, "-");
++ port = strtok((char*) _port, "-");
+ if(port == NULL)
+ goto out;
+
++++++ hal-add-wacom_tabletPC_setserial.diff ++++++
--- /var/tmp/diff_new_pack.J5FPPX/_old 2006-05-07 16:12:49.000000000 +0200
+++ /var/tmp/diff_new_pack.J5FPPX/_new 2006-05-07 16:12:49.000000000 +0200
@@ -67,10 +67,10 @@
+static int debug = FALSE;
+
+
-+int main (int argc, char *argv[])
++int main (int argc, const char *argv[])
+{
+ int i;
-+ int ret_val;
++ int ret_val = EXIT_FAILURE;
+ poptContext popt_context;
+ char *udi = NULL;
+ char *irq = NULL;
@@ -78,7 +78,7 @@
+ char *input_dev = NULL;
+ char cmd[MAX_CMD_LENGTH+1];
+ const char **left_over_args = NULL;
-+ DBusError error;
++ // DBusError error;
+
+ struct poptOption options[] = {
+ {"udi", 's', POPT_ARG_STRING, &udi, 0, "udi of the related tablet device", "UDI"},
++++++ hal-fix-int-size-for-alignment-error-01.patch ++++++
--- hald/linux2/osspec.c
+++ hald/linux2/osspec.c
@@ -543,7 +543,7 @@
int can_suspend;
int can_hibernate;
ssize_t read;
- unsigned int len;
+ size_t len;
char *poweroptions;
FILE *fp;
++++++ hal-fix-map_chassitype_to_formfactor_v2.diff ++++++
diff -Nur fdi/policy/10osvendor/21-storage-methods.fdi fdi/policy/10osvendor/21-storage-methods.fdi
--- fdi/policy/10osvendor/21-storage-methods.fdi 1970-01-01 01:00:00.000000000 +0100
+++ fdi/policy/10osvendor/21-storage-methods.fdi 2006-05-03 15:34:15.000000000 +0200
@@ -0,0 +1,44 @@
+<?xml version="1.0" encoding="UTF-8"?> <!-- -*- SGML -*- -->
+
+<deviceinfo version="0.2">
+ <device>
+ <!-- this is to be able to mount media in drives we cannot poll, e.g. IDE Zip Drives and PC style floppy drives -->
+ <match key="storage.media_check_enabled" bool="false">
+ <match key="storage.no_partitions_hint" bool="true">
+
+ <append key="info.interfaces" type="strlist">org.freedesktop.Hal.Device.Volume</append>
+
+ <append key="org.freedesktop.Hal.Device.Volume.method_names" type="strlist">Mount</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_signatures" type="strlist">ssas</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_execpaths" type="strlist">hal-system-storage-mount</append>
+
+ <append key="org.freedesktop.Hal.Device.Volume.method_names" type="strlist">Unmount</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_signatures" type="strlist">as</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_execpaths" type="strlist">hal-system-storage-unmount</append>
+
+ <append key="org.freedesktop.Hal.Device.Volume.method_names" type="strlist">Eject</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_signatures" type="strlist">as</append>
+ <append key="org.freedesktop.Hal.Device.Volume.method_execpaths" type="strlist">hal-system-storage-eject</append>
+
+ <!-- allow these mount options for all file systems -->
+ <append key="volume.mount.valid_options" type="strlist">ro</append>
+ <append key="volume.mount.valid_options" type="strlist">sync</append>
+ <append key="volume.mount.valid_options" type="strlist">dirsync</append>
+ <append key="volume.mount.valid_options" type="strlist">noatime</append>
+ <append key="volume.mount.valid_options" type="strlist">nodiratime</append>
+ <append key="volume.mount.valid_options" type="strlist">noexec</append>
+ <append key="volume.mount.valid_options" type="strlist">quiet</append>
+
+ <!-- As this is removable media give some leeway -->
+ <append key="volume.mount.valid_options" type="strlist">utf8</append>
+ <append key="volume.mount.valid_options" type="strlist">shortname=</append>
+ <append key="volume.mount.valid_options" type="strlist">codepage=</append>
+ <append key="volume.mount.valid_options" type="strlist">iocharset=</append>
+ <append key="volume.mount.valid_options" type="strlist">umask=</append>
+ <append key="volume.mount.valid_options" type="strlist">uid=</append>
+ <append key="volume.mount.valid_options" type="strlist">flush</append>
+
+ </match>
+ </match>
+ </device>
+</deviceinfo>
diff -Nur fdi/policy/10osvendor/Makefile.am fdi/policy/10osvendor/Makefile.am
--- fdi/policy/10osvendor/Makefile.am 2006-05-03 15:25:23.000000000 +0200
+++ fdi/policy/10osvendor/Makefile.am 2006-05-03 15:35:46.000000000 +0200
@@ -7,6 +7,7 @@
10-laptop-panel-mgmt-policy.fdi \
15-storage-luks.fdi \
20-storage-methods.fdi \
+ 21-storage-methods.fdi \
99-storage-policy-fixed-drives.fdi
if HAVE_SELINUX
++++++ hal-fix-probe_smbios_parse_bug172204.diff ++++++
--- hald/linux2/probing/probe-smbios.c 2006-05-04 18:53:18.000000000 +0200
+++ hald/linux2/probing/probe-smbios.c 2006-05-04 19:34:27.000000000 +0200
@@ -45,7 +45,7 @@
#define DMIPARSER_STATE_SYSTEM 2
#define DMIPARSER_STATE_CHASSIS 3
-#define strbegin(buf, str) (strncmp (buf, str, sizeof (str) - 1) == 0)
+#define strbegin(buf, str) (strncmp (buf, str, strlen(str)) == 0)
/* global */
char *udi = NULL;
++++++ hal-vio-bus.patch ++++++
---
hald/linux2/physdev.c | 46 ++++++++++++++++++++++++++++++++++++++++++++++
1 file changed, 46 insertions(+)
Index: hald/linux2/physdev.c
===================================================================
--- hald/linux2/physdev.c.orig
+++ hald/linux2/physdev.c
@@ -954,6 +954,45 @@ ieee1394_compute_udi (HalDevice *d)
/*--------------------------------------------------------------------------------------------------------------*/
+static HalDevice *
+vio_add (const gchar *sysfs_path, HalDevice *parent)
+{
+ HalDevice *d;
+
+ d = hal_device_new ();
+ hal_device_property_set_string (d, "linux.sysfs_path", sysfs_path);
+ hal_device_property_set_string (d, "linux.sysfs_path_device", sysfs_path);
+ hal_device_property_set_string (d, "info.bus", "vio");
+ if (parent != NULL) {
+ hal_device_property_set_string (d, "info.parent", parent->udi);
+ } else {
+ hal_device_property_set_string (d, "info.parent", "/org/freedesktop/Hal/devices/computer");
+ }
+
+ hal_device_property_set_string (d, "vio.linux.sysfs_path", sysfs_path);
+
+ hal_util_set_driver (d, "info.linux.driver", sysfs_path);
+ hal_util_set_string_from_file (d, "vio.name", sysfs_path, "name");
+
+ return d;
+}
+
+static gboolean
+vio_compute_udi (HalDevice *d)
+{
+ gchar udi[256];
+
+ hal_util_compute_udi (hald_get_gdl (), udi, sizeof (udi),
+ "/org/freedesktop/Hal/devices/vio_%s",
+ hal_device_property_get_string (d, "vio.name"));
+ hal_device_set_udi (d, udi);
+ hal_device_property_set_string (d, "info.udi", udi);
+
+ return TRUE;
+}
+
+/*--------------------------------------------------------------------------------------------------------------*/
+
static inline void
ccw_add_dasd_properties (HalDevice *d, const gchar *sysfs_path)
{
@@ -1445,6 +1484,12 @@ static PhysDevHandler physdev_handler_ie
.remove = physdev_remove
};
+static PhysDevHandler physdev_handler_vio = {
+ .subsystem = "vio",
+ .add = vio_add,
+ .compute_udi = vio_compute_udi,
+ .remove = physdev_remove
+};
/* s390 specific busses */
static PhysDevHandler physdev_handler_ccw = {
@@ -1487,6 +1532,7 @@ static PhysDevHandler *phys_handlers[] =
&physdev_handler_scsi,
&physdev_handler_mmc,
&physdev_handler_ieee1394,
+ &physdev_handler_vio,
&physdev_handler_ccw,
&physdev_handler_ccwgroup,
&physdev_handler_iucv,
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Remember to have fun...
| < Previous | Next > |
--- hald/linux2/osspec.c 2006-05-03 15:26:51.000000000 +0200
+++ hald/linux2/osspec.c 2006-05-03 15:25:23.000000000 +0200
@@ -483,57 +483,64 @@
}
- /* now map the smbios.* properties to our generic system.formfactor property */
- if ((chassis_type = hal_device_property_get_string (d, "smbios.chassis.type")) != NULL) {
- unsigned int i;
-
- /* Map the chassis type from dmidecode.c to a sensible type used in hal
- *
- * See also 3.3.4.1 of the "System Management BIOS Reference Specification,
- * Version 2.3.4" document, available from http://www.dmtf.org/standards/smbios.
- *
- * TODO: figure out WTF the mapping should be; "Lunch Box"? Give me a break :-)
- */
- static const char *chassis_map[] = {
- "Other", "unknown",
- "Unknown", "unknown",
- "Desktop", "desktop",
- "Low Profile Desktop", "desktop",
- "Pizza Box", "server",
- "Mini Tower", "desktop",
- "Tower", "desktop",
- "Portable", "laptop",
- "Laptop", "laptop",
- "Notebook", "laptop",
- "Hand Held", "handheld",
- "Docking Station", "laptop",
- "All In One", "unknown",
- "Sub Notebook", "laptop",
- "Space-saving", "unknown",
- "Lunch Box", "unknown",
- "Main Server Chassis", "server",
- "Expansion Chassis", "unknown",
- "Sub Chassis", "unknown",
- "Bus Expansion Chassis", "unknown",
- "Peripheral Chassis", "unknown",
- "RAID Chassis", "unknown",
- "Rack Mount Chassis", "unknown",
- "Sealed-case PC", "unknown",
- "Multi-system", "unknown",
- NULL
- };
-
- for (i = 0; chassis_map[i] != NULL; i += 2) {
- if (strcmp (chassis_map[i], chassis_type) == 0) {
- /* check if the key is already set to prevent overwrite keys */
- if (!hal_device_has_property(d, "system.formfactor"))
+ /* Use a atomic lock to avoid trouble/overwrite already set value for system.formfactor
+ * from other code paths (e.g. in ACPI/APM/PMU code)
+ */
+ device_property_atomic_update_begin ();
+ if (!hal_device_has_property (d, "system.formfactor")) {
+ /* now map the smbios.* properties to our generic system.formfactor property */
+ if ((chassis_type = hal_device_property_get_string (d, "smbios.chassis.type")) != NULL) {
+ unsigned int i;
+
+ /* Map the chassis type from dmidecode.c to a sensible type used in hal
+ *
+ * See also 3.3.4.1 of the "System Management BIOS Reference Specification,
+ * Version 2.3.4" document, available from http://www.dmtf.org/standards/smbios.
+ *
+ * TODO: figure out WTF the mapping should be; "Lunch Box"? Give me a break :-)
+ */
+ static const char *chassis_map[] = {
+ "Other", "unknown",
+ "Unknown", "unknown",
+ "Desktop", "desktop",
+ "Low Profile Desktop", "desktop",
+ "Pizza Box", "server",
+ "Mini Tower", "desktop",
+ "Tower", "desktop",
+ "Portable", "laptop",
+ "Laptop", "laptop",
+ "Notebook", "laptop",
+ "Hand Held", "handheld",
+ "Docking Station", "laptop",
+ "All In One", "unknown",
+ "Sub Notebook", "laptop",
+ "Space-saving", "unknown",
+ "Lunch Box", "unknown",
+ "Main Server Chassis", "server",
+ "Expansion Chassis", "unknown",
+ "Sub Chassis", "unknown",
+ "Bus Expansion Chassis", "unknown",
+ "Peripheral Chassis", "unknown",
+ "RAID Chassis", "unknown",
+ "Rack Mount Chassis", "unknown",
+ "Sealed-case PC", "unknown",
+ "Multi-system", "unknown",
+ NULL
+ };
+
+ for (i = 0; chassis_map[i] != NULL; i += 2) {
+ if (strcmp (chassis_map[i], chassis_type) == 0) {
hal_device_property_set_string (d, "system.formfactor", chassis_map[i+1]);
- break;
+ break;
+ }
}
+
+ } else {
+ /* set a default value */
+ hal_device_property_set_string (d, "system.formfactor", "unknown");
}
-
}
-
+ device_property_atomic_update_end ();
computer_probing_helper_done (d);
}
@@ -602,10 +609,6 @@
hal_device_property_set_string (root, "system.kernel.machine", un.machine);
}
- /* can be overridden by dmidecode, others */
- hal_device_property_set_string (root, "system.formfactor", "unknown");
-
-
/* Let computer be in TDL while synthesizing all other events because some may write to the object */
hal_device_store_add (hald_get_tdl (), root);
@@ -645,6 +648,8 @@
/* no probing or probing failed */
computer_probing_helper_done (root);
+ /* can be overridden by others, set as default if probing failed */
+ hal_device_property_set_string (root, "system.formfactor", "unknown");
out:
;
}
++++++ hal-fix-mount_on_dev_wo_media_check_support.diff ++++++